import 'package:b2b_graphql_package/modules/account/user_model.dart';

import 'password_available_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';

class AuthRepo {
  var graphQLConfiguration;

  var checkPassword;
  var signInWithPassword;
  var checkMobileAndEmail;
  var addEmailOtp;
  AuthRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future checkPasswordAvailability(String mobileNumber, int isdCode) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var checkPasswordGql = """ 
                  query checkPassword(\$mobileNumber: String, \$isdCode: Int) {
          checkPassword(mobileNumber: \$mobileNumber, isdCode: \$isdCode) {
            _id
            password
            __typename
          }
        }
            """;

    final vble = {"mobileNumber": mobileNumber, "isdCode": isdCode};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(checkPasswordGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var checkPasswordModel = result.data!['checkPassword'];

      if (checkPasswordModel != null && checkPasswordModel.length > 0) {
        checkPassword = checkPasswordFromJson(checkPasswordModel);
        return checkPassword;
      }
    }
    return checkPassword;
  }

  Future signInWithMobileAndPassword(
      String mobileNumber, String password, int isdCode) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var signInGql = """ 
           query login(\$mobileNumber: String, \$password: String, \$isdCode: Int) {
              login(mobileNumber: \$mobileNumber, password: \$password, isdCode: \$isdCode) {
                _id
                __typename
              }
            }
            """;

    final vble = {
      "mobileNumber": mobileNumber,
      "password": password,
      "isdCode": isdCode
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(signInGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var signInModel = result.data!['login'];

      if (signInModel != null && signInModel.length > 0) {
        signInWithPassword = userByIdFromJson(signInModel);
        return signInWithPassword;
      }
    }
    return signInWithPassword;
  }

  Future checkMobileAndEmailAuth(
      String emailId, String mobileNumber, int isdCode) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var checkPasswordGql = """ 
                   query checkMobileAndEmail(
                    \$mobileNumber: String
                    \$emailId: String
                    \$isdCode: Int
                  ) {
                    checkMobileAndEmail(
                      mobileNumber: \$mobileNumber
                      emailId: \$emailId
                      isdCode: \$isdCode
                    ) {
                      isMobile
                      isEmail
                    }
                  }

            """;

    final vble = {
      "emailId": emailId,
      "mobileNumber": mobileNumber,
      "isdCode": isdCode
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(checkPasswordGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var checkmobilemailModel = result.data!['checkMobileAndEmail'];

      if (checkmobilemailModel != null) {
        checkMobileAndEmail = checkMobileEmailFromJson(checkmobilemailModel);
        return checkMobileAndEmail;
      }
    }
    return checkMobileAndEmail;
  }

  Future addEmailOtpAuth(AuthEmailOtpInput authEmailOtpInput) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var checkPasswordGql = """ 
                   mutation addEmailOtpAuth(\$authEmailOtpInput: AuthEmailOtpInput) {
                    addEmailOtpAuth(authEmailOtpInput: \$authEmailOtpInput) {
                      emailId
                    }
                  }


            """;

    final vble = {
      "authEmailOtpInput": authEmailOtpInput,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(checkPasswordGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var addEmailOtpModel = result.data!['addEmailOtpAuth'];

      if (addEmailOtpModel != null) {
        addEmailOtp = authEmailOtpInputFromJson(addEmailOtpModel);
        return addEmailOtp;
      }
    }
    return addEmailOtp;
  }
}
