import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';
import 'category_pack_model.dart';

class CategoryPackWithSetRepo {
  var graphQLConfiguration;

  var categoryPackWithSet;
  var productDetails;
  CategoryPackWithSetRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future<CategoryPackWithSet> getCategoryPackWithSet(
      String categoryLink, int page, int limit, List filter) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var categoryPackGql = """ 
                  query getCategoryPackWithSet(
                    \$categoryLink: String
                    \$page: Int
                    \$limit: Int
                    \$filter: [FilterAttribute]
                  ) {
                    getCategoryPackWithSet(
                      categoryLink: \$categoryLink
                      page: \$page
                      limit: \$limit
                      filter: \$filter
                    ) {
                      pack {
                        _id
                        packSKU
                        moq
                        packImages {
                          packImageName
                          __typename
                        }
                        packName
                        packVariant
                        isOutofstock
                        headSetInformation {
                          setPrice
                          setQuantity
                          __typename
                        }
                        __typename
                      }
                      currentPage
                      totalPages
                      count
                      __typename
                    }
                  }

            """;

    final vble = {
      "categoryLink": categoryLink,
      "page": page,
      "limit": limit,
      "filter": filter
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(categoryPackGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var categoryPack = result.data!['getCategoryPackWithSet'];

      if (categoryPack != null && categoryPack.length > 0) {
        categoryPackWithSet = categoryPackWithSetFromJson(categoryPack);
      }
      return categoryPackWithSet;
    }
    return categoryPackWithSet;
  }

  Future getProductList(
      String categoryLink, int page, int limit, List filter) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var productListGql = """ 
                    query getProductList(
                    \$categoryLink: String
                    \$page: Int
                    \$limit: Int
                    \$filter: [FilterAttribute]
                  ) {
                    getProductList(
                      categoryLink: \$categoryLink
                      page: \$page
                      limit: \$limit
                      filter: \$filter
                    ) {
                      product {
                        _id
                        productId
                        name
                        description
                        imageId
                        type
                        moq
                        isOutofstock
                        isMultiple
                        price {
                          sellingPrice
                          mrp
                          discount
                          minPrice
                          maxPrice
                          type
                          isSamePrice
                          __typename
                        }
                        images {
                          imageName
                          position
                          __typename
                        }
                        __typename
                      }
                      currentPage
                      totalPages
                      count
                      __typename
                    }
                  }

            """;

    final vble = {
      "categoryLink": categoryLink,
      "page": page,
      "limit": limit,
      "filter": filter
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(productListGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var categoryPack = result.data!['getProductList'];

      if (categoryPack != null && categoryPack.length > 0) {
        categoryPackWithSet = productListFromJson(categoryPack);
      }
      return categoryPackWithSet;
    }
    return categoryPackWithSet;
  }

  Future getProduct(String id, bool isDefault, List variants) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var productGql = """ 
                    query getProduct(\$id: String, \$variants: [VariantsInput], \$isDefault: Boolean) {
                    getProduct(id: \$id, variants: \$variants, isDefault: \$isDefault) {
                        _id
    			isMultiple
          categoryIds {
            _id
            categoryName
            link
            level
          }
          imageId
    			productId
          configurationDate
          name
          description
          details
    			packVariant
          moq
          isOutofstock
          isCustomizable
          type
          skuId
          skuIds {
            skuId
            originalQty
            quantity
            price {
              sellingPrice
              mrp
              priceRange {
                sellingPrice
                mrp
                minQty
                maxQty
              }
            }
            attribute {
              labelName
              attributeFieldId
              attributeFieldValueId
              fieldValue
              colorCode
            }
          }
          children {
            quantity
            price {
              sellingPrice
              mrp
              priceRange {
                discount
                sellingPrice
                mrp
                minQty
                maxQty
              }
            }
            attribute {
              labelName
              fieldValue
              attributeFieldId
              attributeFieldValueId
              colorCode
            }
          }
          price{
              sellingPrice
              minPrice
              maxPrice
              mrp
              type
              discount
              priceRange {
                id
                minQty
                maxQty
                discount
                sellingPrice
              }
              priceRangeAll {
                id
                minQty
                maxQty
                discount
                sellingPrice
              }
            }
    
    	variantTypes{
      	type
        attributeFieldId
      	fieldValue {
          attributeFieldValueId
          attributeFieldId
          labelName
          colorCode    
          enable     
          disabled
        }
    }
    	images {
        imageName
        position
      }
    	mergeAttribute{
      	type
        attributeFieldId
      	fieldValue 
    }
    	filterAttribute{
      	type
        attributeFieldId
      	fieldValue {
          id
          attributeFieldValueId
          attributeFieldId
          labelName
          colorCode         
        }
    }
                    }
                  }

            """;

    final vble = {
      "id": id,
      "isDefault": isDefault,
      "variants": variants,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(productGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));
    // print('single product');
    if (!result.hasException) {
      var product = result.data!['getProduct'];
      // print(product['variantTypes']);
      if (product != null && product.length > 0) {
        productDetails = productDetailsFromJson(product);
      }
      return productDetails;
    }
    return productDetails;
  }
}
