DelhiveryShippingFees delhiveryShippingFeesFromJson(dynamic str) =>
    (DelhiveryShippingFees.fromJson(str));

class DelhiveryShippingFees {
  late final double? fees;
  late final int? shippingIGST;
  late final double? shippingSGST;
  late final double? shippingCGST;
  late final String sTypename;

  DelhiveryShippingFees(
      {required this.fees,
      required this.shippingIGST,
      required this.shippingSGST,
      required this.shippingCGST,
      required this.sTypename});

  DelhiveryShippingFees.fromJson(Map<String, dynamic> json) {
    fees = json['fees'];
    shippingIGST = json['shippingIGST'];
    shippingSGST = json['shippingSGST'];
    shippingCGST = json['shippingCGST'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fees'] = this.fees;
    data['shippingIGST'] = this.shippingIGST;
    data['shippingSGST'] = this.shippingSGST;
    data['shippingCGST'] = this.shippingCGST;
    data['__typename'] = this.sTypename;
    return data;
  }
}

List<CartForBooking> cartForBookingListFromJson(dynamic str) =>
    List<CartForBooking>.from(str.map((x) => CartForBooking.fromJson(x)));

class CartForBooking {
  late final String sId;
  late final BookingPack? pack;
  late final Set? set;
  late final String sTypename;

  CartForBooking(
      {required this.sId,
      required this.pack,
      required this.set,
      required this.sTypename});

  CartForBooking.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    pack = json['pack'] != null ? new BookingPack.fromJson(json['pack']) : null;
    set = json['set'] != null ? new Set.fromJson(json['set']) : null;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    if (this.pack != null) {
      data['pack'] = this.pack!.toJson();
    }
    if (this.set != null) {
      data['set'] = this.set!.toJson();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class BookingPack {
  late final String? packName;
  late final String? packSKU;
  late final String? packId;
  late final int? moq;
  late final List<String>? categoryId;
  late final String? packVariant;
  late final String? packImage;
  late final String sTypename;

  BookingPack(
      {required this.packName,
      required this.packSKU,
      required this.packId,
      required this.moq,
      required this.categoryId,
      required this.packVariant,
      required this.packImage,
      required this.sTypename});

  BookingPack.fromJson(Map<String, dynamic> json) {
    packName = json['packName'];
    packSKU = json['packSKU'];
    packId = json['packId'];
    moq = json['moq'];
    categoryId = json['categoryId'].cast<String>();
    packVariant = json['packVariant'];
    packImage = json['packImage'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['packName'] = this.packName;
    data['packSKU'] = this.packSKU;
    data['packId'] = this.packId;
    data['moq'] = this.moq;
    data['categoryId'] = this.categoryId;
    data['packVariant'] = this.packVariant;
    data['packImage'] = this.packImage;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Set {
  late final String? setCode;
  late final String? setId;
  late final List<Sku>? sku;
  late final String sTypename;

  Set(
      {required this.setCode,
      required this.setId,
      required this.sku,
      required this.sTypename});

  Set.fromJson(Map<String, dynamic> json) {
    setCode = json['setCode'];
    setId = json['setId'];
    if (json['sku'] != null) {
      sku = [];
      json['sku'].forEach((v) {
        sku!.add(new Sku.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setCode'] = this.setCode;
    data['setId'] = this.setId;
    if (this.sku != null) {
      data['sku'] = this.sku!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Sku {
  late final String? sku;
  late final int? setSkuPrice;
  late final int? setQuantity;
  late final String? skuId;
  late final String? styleCode;
  late final String? variationType;
  late final int? b2cSellingPrice;
  late final int? b2bSellingPrice;
  late final int? mrp;
  late final int? discount;
  late final String? productName;
  late final String? iNTsku;
  late final String? sizeAttributeSettingId;
  late final String? sizeAttributeSettingFieldValueId;
  late final String? colorAttributeSettingId;
  late final String? colorAttributeSettingFieldValueId;
  late final String? gstTypeId;
  late final int? gstValue;
  late final String? colorAttributeFieldValue;
  late final String? sizeAttributeFieldValue;
  late final String? colorAttributeName;
  late final String? sizeAttributeName;
  late final String sTypename;

  Sku(
      {required this.sku,
      required this.setSkuPrice,
      required this.setQuantity,
      required this.skuId,
      required this.styleCode,
      required this.variationType,
      required this.b2cSellingPrice,
      required this.b2bSellingPrice,
      required this.mrp,
      required this.discount,
      required this.productName,
      required this.iNTsku,
      required this.sizeAttributeSettingId,
      required this.sizeAttributeSettingFieldValueId,
      required this.colorAttributeSettingId,
      required this.colorAttributeSettingFieldValueId,
      required this.gstTypeId,
      required this.gstValue,
      required this.colorAttributeFieldValue,
      required this.sizeAttributeFieldValue,
      required this.colorAttributeName,
      required this.sizeAttributeName,
      required this.sTypename});

  Sku.fromJson(Map<String, dynamic> json) {
    sku = json['sku'];
    setSkuPrice = json['setSkuPrice'];
    setQuantity = json['setQuantity'];
    skuId = json['skuId'];
    styleCode = json['styleCode'];
    variationType = json['variationType'];
    b2cSellingPrice = json['b2cSellingPrice'];
    b2bSellingPrice = json['b2bSellingPrice'];
    mrp = json['mrp'];
    discount = json['discount'];
    productName = json['productName'];
    iNTsku = json['INTsku'];
    sizeAttributeSettingId = json['sizeAttributeSettingId'];
    sizeAttributeSettingFieldValueId = json['sizeAttributeSettingFieldValueId'];
    colorAttributeSettingId = json['colorAttributeSettingId'];
    colorAttributeSettingFieldValueId =
        json['colorAttributeSettingFieldValueId'];
    gstTypeId = json['gstTypeId'];
    gstValue = json['gstValue'];
    colorAttributeFieldValue = json['colorAttributeFieldValue'];
    sizeAttributeFieldValue = json['sizeAttributeFieldValue'];
    colorAttributeName = json['colorAttributeName'];
    sizeAttributeName = json['sizeAttributeName'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['sku'] = this.sku;
    data['setSkuPrice'] = this.setSkuPrice;
    data['setQuantity'] = this.setQuantity;
    data['skuId'] = this.skuId;
    data['styleCode'] = this.styleCode;
    data['variationType'] = this.variationType;
    data['b2cSellingPrice'] = this.b2cSellingPrice;
    data['b2bSellingPrice'] = this.b2bSellingPrice;
    data['mrp'] = this.mrp;
    data['discount'] = this.discount;
    data['productName'] = this.productName;
    data['INTsku'] = this.iNTsku;
    data['sizeAttributeSettingId'] = this.sizeAttributeSettingId;
    data['sizeAttributeSettingFieldValueId'] =
        this.sizeAttributeSettingFieldValueId;
    data['colorAttributeSettingId'] = this.colorAttributeSettingId;
    data['colorAttributeSettingFieldValueId'] =
        this.colorAttributeSettingFieldValueId;
    data['gstTypeId'] = this.gstTypeId;
    data['gstValue'] = this.gstValue;
    data['colorAttributeFieldValue'] = this.colorAttributeFieldValue;
    data['sizeAttributeFieldValue'] = this.sizeAttributeFieldValue;
    data['colorAttributeName'] = this.colorAttributeName;
    data['sizeAttributeName'] = this.sizeAttributeName;
    data['__typename'] = this.sTypename;
    return data;
  }
}
