import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';

import './chcekout_model.dart';

class CheckoutRepo {
  var graphQLConfiguration;

  var delhivaryFees;
  var cartSkuWeight;
  var cartBooking = [];
  CheckoutRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future getDelhiveryShippingFees(
      int deliveryPincode, double weight, String providerName) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var delhiveryShippingFeeGql = """ 
                 query getDelhiveryShippingFees(
                \$deliveryPincode: Float
                \$weight: Float
                \$providerName: String
              ) {
                getDelhiveryShippingFees(
                  deliveryPincode: \$deliveryPincode
                  weight: \$weight
                  providerName: \$providerName
                ) {
                  fees
                  shippingIGST
                  shippingSGST
                  shippingCGST
                  __typename
                }
              }
            """;

    final vble = {
      "deliveryPincode": deliveryPincode,
      "weight": weight,
      "providerName": providerName,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(delhiveryShippingFeeGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var shippingFees = result.data!['getDelhiveryShippingFees'];

      if (shippingFees != null) {
        delhivaryFees = delhiveryShippingFeesFromJson(shippingFees);
      }
      return delhivaryFees;
    }
    return delhivaryFees;
  }

  Future getCartSkuWeight(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartSkuWeightGql = """ 
               query getCartSkuWeight(\$userId: String) {
                getCartSkuWeight(userId: \$userId)
              }
            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartSkuWeightGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var skuWeight = result.data!['getCartSkuWeight'];

      if (skuWeight != null) {
        cartSkuWeight = skuWeight;
      }
      return cartSkuWeight;
    }
    return cartSkuWeight;
  }

  Future getCartForBooking(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartBookingGql = """ 
              query getCartForBooking(\$userId: String) {
              getCartForBooking(userId: \$userId) {
                _id
                pack {
                  packName
                  packSKU
                  packId
                  moq
                  categoryId
                  packVariant
                  packImage
                  __typename
                }
                set {
                  setCode
                  setId
                  sku {
                    sku
                    setSkuPrice
                    setQuantity
                    skuId
                    sku
                    styleCode
                    variationType
                    b2cSellingPrice
                    b2bSellingPrice
                    mrp
                    discount
                    productName
                    INTsku
                    sizeAttributeSettingId
                    sizeAttributeSettingFieldValueId
                    colorAttributeSettingId
                    colorAttributeSettingFieldValueId
                    gstTypeId
                    gstValue
                    colorAttributeFieldValue
                    sizeAttributeFieldValue
                    colorAttributeName
                    sizeAttributeName
                    __typename
                  }
                  __typename
                }
                __typename
              }
            }

            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartBookingGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var bookingCart = result.data!['getCartForBooking'];

      if (bookingCart != null && bookingCart.length > 0) {
        cartBooking = cartForBookingListFromJson(bookingCart);
      }
      return cartBooking;
    }
    return cartBooking;
  }
}
