OrderModel orderListFromJson(dynamic str) => (OrderModel.fromJson(str));

class OrderModel {
  late final List<Order> order;
  late final int currentPage;
  late final int totalPages;
  late final int count;
  late final String sTypename;

  OrderModel(
      {required this.order,
      required this.currentPage,
      required this.totalPages,
      required this.count,
      required this.sTypename});

  OrderModel.fromJson(Map<String, dynamic> json) {
    if (json['order'] != null) {
      order = [];
      json['order'].forEach((v) {
        order.add(new Order.fromJson(v));
      });
    }
    currentPage = json['currentPage'];
    totalPages = json['totalPages'];
    count = json['count'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.order != null) {
      data['order'] = this.order.map((v) => v.toJson()).toList();
    }
    data['currentPage'] = this.currentPage;
    data['totalPages'] = this.totalPages;
    data['count'] = this.count;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Order {
  late final String orderId;
  late final String orderDate;
  late final int orderStatus;
  late final double totalAmount;
  late final double shippingFees;
  late final String sId;
  late final Price? price;
  late final String sTypename;

  Order(
      {required this.orderId,
      required this.orderDate,
      required this.orderStatus,
      required this.totalAmount,
      required this.shippingFees,
      required this.sId,
      required this.price,
      required this.sTypename});

  Order.fromJson(Map<String, dynamic> json) {
    orderId = json['orderId'];
    orderDate = json['orderDate'];
    orderStatus = json['orderStatus'];
    totalAmount =
        json['totalAmount'] != null ? json['totalAmount'].toDouble() : 0.0;
    shippingFees =
        json['shippingFees'] != null ? json['shippingFees'].toDouble() : 0.0;
    sId = json['_id'];
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['orderId'] = this.orderId;
    data['orderDate'] = this.orderDate;
    data['orderStatus'] = this.orderStatus;
    data['totalAmount'] = this.totalAmount;
    data['shippingFees'] = this.shippingFees;
    data['_id'] = this.sId;
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Price {
  late final double? totalPrice;
  late final String? sTypename;

  Price({required this.totalPrice, required this.sTypename});

  Price.fromJson(Map<String, dynamic> json) {
    totalPrice = json['totalPrice'].toDouble();
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['totalPrice'] = this.totalPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}
