class OrderProductDetails {
  late final String? isCustomizable;
  late final String? code;
  late final String? productName;
  late final String? productId;
  late final String? imageId;
  late final String? skuId;
  late final String? productDescription;
  late final String? type;
  late final bool? isMultiple;
  late final List<Category>? category;
  late final List<Brand>? brand;
  late final List<Attribute>? attribute;
  late final Price? price;
  late final int? totalPieces;
  late final int? qty;
  late final String? imageUrl;
  late final List<SkuIds>? skuIds;
  late final List<SkuIds>? children;

  OrderProductDetails({
    required this.isCustomizable,
    required this.code,
    required this.productName,
    required this.productId,
    required this.imageId,
    required this.skuId,
    required this.productDescription,
    required this.type,
    required this.isMultiple,
    required this.category,
    required this.brand,
    required this.attribute,
    required this.price,
    required this.totalPieces,
    required this.qty,
    required this.imageUrl,
    required this.skuIds,
    required this.children,
  });

  OrderProductDetails.fromJson(Map<String, dynamic> json) {
    isCustomizable = json['isCustomizable'];
    code = json['code'];
    productName = json['productName'];
    productId = json['productId'];
    imageId = json['imageId'];
    skuId = json['skuId'];
    productDescription = json['productDescription'];
    type = json['type'];
    isMultiple = json['isMultiple'];
    category = <Category>[];
    if (json['category'] != null) {
      json['category'].forEach((v) {
        category!.add(new Category.fromJson(v));
      });
    }
    brand = <Brand>[];
    if (json['brand'] != null) {
      json['brand'].forEach((v) {
        brand!.add(new Brand.fromJson(v));
      });
    }
    attribute = <Attribute>[];
    if (json['attribute'] != null) {
      json['attribute'].forEach((v) {
        attribute!.add(new Attribute.fromJson(v));
      });
    }
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    totalPieces = json['totalPieces'];
    qty = json['qty'];
    imageUrl = json['imageUrl'];
    skuIds = <SkuIds>[];
    if (json['skuIds'] != null) {
      json['skuIds'].forEach((v) {
        skuIds!.add(new SkuIds.fromJson(v));
      });
    }
    children = <SkuIds>[];
    if (json['children'] != null) {
      json['children'].forEach((v) {
        children!.add(new SkuIds.fromJson(v));
      });
    }
  }

  OrderProductDetails.fromRequestJson(dynamic json) {
    isCustomizable = null;
    code = json.code;
    productName = json.productName;
    productId = json.productId;
    imageId = json.imageId;
    skuId = json.skuId;
    productDescription = json.productDescription;
    type = json.type;
    isMultiple = json.isMultiple;
    category = <Category>[];
    if (json.category != null) {
      json.category.forEach((v) {
        category!.add(new Category.fromRequestJson(v));
      });
    }
    brand = <Brand>[];
    if (json.brand != null) {
      json.brand.forEach((v) {
        brand!.add(new Brand.fromRequestJson(v));
      });
    }
    attribute = <Attribute>[];
    if (json.attribute != null) {
      json.attribute.forEach((v) {
        attribute!.add(new Attribute.fromRequestJson(v));
      });
    }
    price = json.price != null ? new Price.fromRequestJson(json.price) : null;
    totalPieces = json.totalPieces;
    qty = json.qty;
    imageUrl = json.imageUrl;
    skuIds = <SkuIds>[];
    if (json.skuIds != null) {
      json.skuIds.forEach((v) {
        skuIds!.add(new SkuIds.fromRequestJson(v));
      });
    }
    children = <SkuIds>[];
    if (json.children != null) {
      json.children.forEach((v) {
        children!.add(new SkuIds.fromRequestJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['isCustomizable'] = this.isCustomizable;
    data['code'] = this.code;
    data['productName'] = this.productName;
    data['productId'] = this.productId;
    data['imageId'] = this.imageId;
    data['skuId'] = this.skuId;
    data['productDescription'] = this.productDescription;
    data['type'] = this.type;
    data['isMultiple'] = this.isMultiple;
    if (this.category != null) {
      data['category'] = this.category!.map((v) => v.toJson()).toList();
    }
    if (this.brand != null) {
      data['brand'] = this.brand!.map((v) => v.toJson()).toList();
    }
    if (this.attribute != null) {
      data['attribute'] = this.attribute!.map((v) => v.toJson()).toList();
    }
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['totalPieces'] = this.totalPieces;
    data['qty'] = this.qty;
    data['imageUrl'] = this.imageUrl;
    if (this.skuIds != null) {
      data['skuIds'] = this.skuIds!.map((v) => v.toJson()).toList();
    }
    if (this.children != null) {
      data['children'] = this.children!.map((v) => v.toJson()).toList();
    }

    return data;
  }
}

class Category {
  late final String? sId;
  late final String? categoryName;

  Category({required this.sId, required this.categoryName});

  Category.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    categoryName = json['categoryName'];
  }

  Category.fromRequestJson(dynamic json) {
    sId = json.sId;
    categoryName = json.categoryName;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['categoryName'] = this.categoryName;

    return data;
  }
}

class Brand {
  late final String? brandName;

  Brand({required this.brandName});

  Brand.fromJson(Map<String, dynamic> json) {
    brandName = json['brandName'];
  }

  Brand.fromRequestJson(dynamic json) {
    brandName = json.brandName;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['brandName'] = this.brandName;
    return data;
  }
}

class Attribute {
  late final String? fieldName;
  late final String? fieldValue;
  late final String? colorCode;

  Attribute({
    required this.fieldName,
    required this.fieldValue,
    required this.colorCode,
  });

  Attribute.fromJson(Map<String, dynamic> json) {
    fieldName = json['fieldName'];
    fieldValue = json['fieldValue'];
    colorCode = json['colorCode'];
  }

  Attribute.fromRequestJson(dynamic json) {
    fieldName = json.fieldName;
    fieldValue = json.fieldValue;
    colorCode = json.colorCode;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fieldName'] = this.fieldName;
    data['fieldValue'] = this.fieldValue;
    data['colorCode'] = this.colorCode;

    return data;
  }
}

class Price {
  late final double? mrp;
  late final double? sellingPrice;
  late final double? discount;
  late final double? totalPrice;
  late final double? gstLabelName;
  late final double? withOutGstPrice;
  late final double? sgstLabelName;
  late final double? cgstLabelName;
  late final double? totalSgst;
  late final double? totalCgst;
  late final double? withOutSCGstPrice;
  late final double? totalGst;

  Price({
    required this.mrp,
    required this.sellingPrice,
    required this.discount,
    required this.totalPrice,
    required this.gstLabelName,
    required this.withOutGstPrice,
    required this.sgstLabelName,
    required this.cgstLabelName,
    required this.totalSgst,
    required this.totalCgst,
    required this.withOutSCGstPrice,
    required this.totalGst,
  });

  Price.fromJson(Map<String, dynamic> json) {
    mrp = makeDouble(json['mrp']);
    sellingPrice = makeDouble(json['sellingPrice']);
    discount = makeDouble(json['discount']);
    totalPrice = makeDouble(json['totalPrice']);
    gstLabelName = makeDouble(json['gstLabelName']);
    withOutGstPrice = makeDouble(json['withOutGstPrice']);
    sgstLabelName = makeDouble(json['sgstLabelName']);
    cgstLabelName = makeDouble(json['cgstLabelName']);
    totalSgst = makeDouble(json['totalSgst']);
    totalCgst = makeDouble(json['totalCgst']);
    withOutSCGstPrice = makeDouble(json['withOutSCGstPrice']);
    totalGst = makeDouble(json['totalGst']);
  }

  Price.fromRequestJson(dynamic json) {
    mrp = makeDouble(json.mrp);
    sellingPrice = makeDouble(json.sellingPrice);
    discount = makeDouble(json.discount);
    totalPrice = makeDouble(json.totalPrice);
    gstLabelName = makeDouble(json.gstLabelName);
    withOutGstPrice = makeDouble(json.withOutGstPrice);
    sgstLabelName = makeDouble(json.sgstLabelName);
    cgstLabelName = makeDouble(json.cgstLabelName);
    totalSgst = makeDouble(json.totalSgst);
    totalCgst = makeDouble(json.totalCgst);
    withOutSCGstPrice = makeDouble(json.withOutSCGstPrice);
    totalGst = makeDouble(json.totalGst);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['mrp'] = this.mrp;
    data['sellingPrice'] = this.sellingPrice;
    data['discount'] = this.discount;
    data['totalPrice'] = this.totalPrice;
    data['gstLabelName'] = this.gstLabelName;
    data['withOutGstPrice'] = this.withOutGstPrice;
    data['sgstLabelName'] = this.sgstLabelName;
    data['cgstLabelName'] = this.cgstLabelName;
    data['totalSgst'] = this.totalSgst;
    data['totalCgst'] = this.totalCgst;
    data['withOutSCGstPrice'] = this.withOutSCGstPrice;
    data['totalGst'] = this.totalGst;

    return data;
  }
}

class SkuIds {
  late final String? skuId;
  late final String? imageId;
  late final String? styleCode;
  late final String? sku;
  late final List<Attribute>? attribute;
  late final List<Category>? category;
  late final Brand? brand;
  late final String? productDimension;
  late final String? packingDimension;
  late final num? weight;
  late final String? productId;
  late final String? type;
  late final bool? isMultiple;
  late final String? productName;
  late final String? imageUrl;
  late final String? productDescription;
  late final Price? price;
  late final int? qty;

  SkuIds({
    required this.skuId,
    required this.imageId,
    required this.styleCode,
    required this.sku,
    required this.attribute,
    required this.category,
    required this.brand,
    required this.productDimension,
    required this.packingDimension,
    required this.weight,
    required this.productId,
    required this.type,
    required this.isMultiple,
    required this.productName,
    required this.imageUrl,
    required this.productDescription,
    required this.price,
    required this.qty,
  });

  SkuIds.fromJson(Map<String, dynamic> json) {
    skuId = json['skuId'];
    imageId = json['imageId'];
    styleCode = json['styleCode'];
    sku = json['sku'];
    if (json['attribute'] != null) {
      attribute = <Attribute>[];
      json['attribute'].forEach((v) {
        attribute!.add(new Attribute.fromJson(v));
      });
    }
    if (json['category'] != null) {
      category = <Category>[];
      json['category'].forEach((v) {
        category!.add(new Category.fromJson(v));
      });
    }
    brand = json['brand'] != null ? new Brand.fromJson(json['brand']) : null;
    productDimension = json['productDimension'];
    packingDimension = json['packingDimension'];
    weight = json['weight'];
    productId = json['productId'];
    type = json['type'];
    isMultiple = json['isMultiple'];
    productName = json['productName'];
    imageUrl = json['imageUrl'];
    productDescription = json['productDescription'];
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    qty = json['qty'];
  }

  SkuIds.fromRequestJson(dynamic json) {
    skuId = json.skuId;
    imageId = json.imageId;
    styleCode = json.styleCode;
    sku = json.sku;
    if (json.attribute != null) {
      attribute = <Attribute>[];
      json.attribute.forEach((v) {
        attribute!.add(new Attribute.fromRequestJson(v));
      });
    }
    if (json.category != null) {
      category = <Category>[];
      json.category.forEach((v) {
        category!.add(new Category.fromRequestJson(v));
      });
    }
    brand = json.brand != null ? new Brand.fromRequestJson(json.brand) : null;
    productDimension = json.productDimension;
    packingDimension = json.packingDimension;
    weight = json.weight;
    productId = json.productId;
    type = json.type;
    isMultiple = json.isMultiple;
    productName = json.productName;
    imageUrl = json.imageUrl;
    productDescription = json.productDescription;
    price = json.price != null ? new Price.fromRequestJson(json.price) : null;
    qty = json.qty;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['skuId'] = this.skuId;
    data['imageId'] = this.imageId;
    data['styleCode'] = this.styleCode;
    data['sku'] = this.sku;
    if (this.attribute != null) {
      data['attribute'] = this.attribute!.map((v) => v.toJson()).toList();
    }
    if (this.category != null) {
      data['category'] = this.category!.map((v) => v.toJson()).toList();
    }
    if (this.brand != null) {
      data['brand'] = this.brand!.toJson();
    }
    data['productDimension'] = this.productDimension;
    data['packingDimension'] = this.packingDimension;
    data['weight'] = this.weight;
    data['productId'] = this.productId;
    data['type'] = this.type;
    data['isMultiple'] = this.isMultiple;
    data['productName'] = this.productName;
    data['imageUrl'] = this.imageUrl;
    data['productDescription'] = this.productDescription;
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['qty'] = this.qty;

    return data;
  }
}

class SkuPrice {
  late final double? mrp;
  late final double? sellingPrice;
  late final double? discount;
  late final double? rangeDiscount;
  late final double? totalPrice;
  late final double? gstLabelName;
  late final double? withOutGstPrice;
  late final double? sgstLabelName;
  late final double? cgstLabelName;
  late final double? totalSgst;
  late final double? totalCgst;
  late final double? withOutSCGstPrice;
  late final double? totalGst;
  late final String? sTypename;

  SkuPrice(
      {required this.mrp,
      required this.sellingPrice,
      required this.discount,
      required this.rangeDiscount,
      required this.totalPrice,
      required this.gstLabelName,
      required this.withOutGstPrice,
      required this.sgstLabelName,
      required this.cgstLabelName,
      required this.totalSgst,
      required this.totalCgst,
      required this.withOutSCGstPrice,
      required this.totalGst,
      required this.sTypename});

  SkuPrice.fromJson(Map<String, dynamic> json) {
    mrp = makeDouble(json['mrp']);
    sellingPrice = makeDouble(json['sellingPrice']);
    discount = makeDouble(json['discount']);
    rangeDiscount = makeDouble(json['rangeDiscount']);
    totalPrice = makeDouble(json['totalPrice']);
    gstLabelName = makeDouble(json['gstLabelName']);
    withOutGstPrice = makeDouble(json['withOutGstPrice']);
    sgstLabelName = makeDouble(json['sgstLabelName']);
    cgstLabelName = makeDouble(json['cgstLabelName']);
    totalSgst = makeDouble(json['totalSgst']);
    totalCgst = makeDouble(json['totalCgst']);
    withOutSCGstPrice = makeDouble(json['withOutSCGstPrice']);
    totalGst = makeDouble(json['totalGst']);
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['mrp'] = this.mrp;
    data['sellingPrice'] = this.sellingPrice;
    data['discount'] = this.discount;
    data['rangeDiscount'] = this.rangeDiscount;
    data['totalPrice'] = this.totalPrice;
    data['gstLabelName'] = this.gstLabelName;
    data['withOutGstPrice'] = this.withOutGstPrice;
    data['sgstLabelName'] = this.sgstLabelName;
    data['cgstLabelName'] = this.cgstLabelName;
    data['totalSgst'] = this.totalSgst;
    data['totalCgst'] = this.totalCgst;
    data['withOutSCGstPrice'] = this.withOutSCGstPrice;
    data['totalGst'] = this.totalGst;
    data['__typename'] = this.sTypename;
    return data;
  }
}

double makeDouble(num? value) {
  return value != null ? value.toDouble() : 0.0;
  // return (field ?? 0).toDouble();
}
