import 'package:b2b_graphql_package/modules/single_pack/single_pack_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';

class SinglePackRepo {
  var graphQLConfiguration;

  var singlePack;
  var checkCODByCategoryAvai = false;
  var cancelCategory;
  var deliveryServiceAbility;
  var similarPackDetails;
  var loacalRecentPack;
  SinglePackRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future<SinglePack> getSinglePack(String packId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var singlePackGql = """ 
                  query getSinglePack(\$packId: String) {
                  getSinglePack(packId: \$packId) {
                    _id
                    packName
                    packDescription
                    moq
                    packVariant
                    categoryId
                    packColorLabel {
                      colorId
                      colorName
                      appletName
                      __typename
                    }
                    headSetInformation {
                      setPrice
                      setQuantity
                      mergeAttribute {
                        labelName
                        fieldSetting
                        fieldValue
                        __typename
                      }
                      __typename
                    }
                    packImages {
                      _id
                      packImageName
                      __typename
                    }
                    packOptions {
                      packSetTypeName
                      packSetValue {
                        _id
                        skuIds {
                          skuId {
                            _id
                            sku
                            b2bSellingPrice
                            __typename
                          }
                          setSKUprice
                          __typename
                        }
                        count
                        setPrice
                        setQuantity
                        maximumQuantity
                        setLabelName
                        setColorId
                        setAppletName
                        __typename
                      }
                      __typename
                    }
                    __typename
                  }
                }

            """;

    final vble = {
      "packId": packId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(singlePackGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var singlePackSet = result.data!['getSinglePack'];

      if (singlePackSet != null && singlePackSet.length > 0) {
        singlePack = singlePackFromJson(singlePackSet);
      }
      return singlePack;
    }
    return singlePack;
  }

  Future checkCODByCategory(List categoryIds) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var checkCODByCategoryGql = """ 
                  query checkCODByCategory(\$categoryIds: [String]) {
                checkCODByCategory(categoryIds: \$categoryIds)
              }

            """;

    final vble = {
      "categoryIds": categoryIds,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(checkCODByCategoryGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var checkCOD = result.data!['checkCODByCategory'];

      if (checkCOD != null) {
        checkCODByCategoryAvai = checkCOD;
      }
      return checkCODByCategoryAvai;
    }
    return checkCODByCategoryAvai;
  }

  Future checkCancelCategoryForDetailPage(List categoryIds) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cancelCategoryForDetailPageGql = """ 
                  query checkCancelCategoryForDetailPage(\$categoryIds: [String]) {
                checkCancelCategoryForDetailPage(categoryIds: \$categoryIds) {
                  isReturnable
                  __typename
                }
              }
            """;

    final vble = {
      "categoryIds": categoryIds,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cancelCategoryForDetailPageGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var cancelCategory = result.data!['checkCancelCategoryForDetailPage'];

      if (cancelCategory != null) {
        cancelCategory = checkCancelCategoryForDetailPageJson(cancelCategory);
      }
      return cancelCategory;
    }
    return cancelCategory;
  }

  Future getDelhiveryServiceability(
      int deliveryPincode, String providerName) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var delhiveryServiceabilityGql = """ 
               query getDelhiveryServiceability(
                \$deliveryPincode: Float
                \$providerName: String
              ) {
                getDelhiveryServiceability(
                  deliveryPincode: \$deliveryPincode
                  providerName: \$providerName
                ) {
                  pre_paid
                  cash
                  pickup
                  cod
                  estimate
                  __typename
                }
              }
            """;

    final vble = {
      "deliveryPincode": deliveryPincode,
      "providerName": providerName
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(delhiveryServiceabilityGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var deliveryService = result.data!['getDelhiveryServiceability'];

      if (deliveryService != null) {
        deliveryServiceAbility = delhiveryServiceabilityJson(deliveryService);
      }
      return deliveryServiceAbility;
    }
    return deliveryServiceAbility;
  }

  Future getSimilarPack(String packId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var similarPackGql = """ 
               query getSimilarPack(\$packId: String) {
                getSimilarPack(packId: \$packId) {
                  _id
                  packName
                  packId
                  setId
                  packImage
                  setPrice
                  __typename
                }
              }
            """;

    final vble = {"packId": packId};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(similarPackGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var similarPack = result.data!['getSimilarPack'];

      if (similarPack != null) {
        similarPackDetails = similarPackFromJson(similarPack);
      }
      return similarPackDetails;
    }
    return similarPackDetails;
  }

  Future getLocalRecentPack(List packIds) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var localRecentPackGql = """ 
             query getLocalRecentPack(\$packDetails: localPackInput) {
                  getLocalRecentPack(packDetails: \$packDetails) {
                    _id
                    packName
                    packId
                    setId
                    packImage
                    setPrice
                    __typename
                  }
                }

            """;

    final vble = {
      "packIds": packIds,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(localRecentPackGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var loaclPack = result.data!['getLocalRecentPack'];

      if (loaclPack != null) {
        loacalRecentPack = localRecentPackFromJson(loaclPack);
      }
      return loacalRecentPack;
    }
    return loacalRecentPack;
  }
}
